<?php

/**
 * @file
 */

class pay_method_direct_upay extends pay_method_direct {

  // Always assume this is a 'upay_direct' payment, since we won't get more specific.
  var $payment_type = 'upay';
  var $upay_site_id = '';
  var $ext_trans_id_prefix = '';
  var $url_live = '';
  var $url_test = '';
  var $test_mode = '';
  var $logging = '';
  var $confirmation_url = '';
  var $receives_post_back = '';
  var $receives_posting_key = '';

  function available_currencies() {
    return array('USD');
  }

  /**
   * This method will be called on a return response (e.g. PayPal IPN)
   * including an unfiltered version of the $_REQUEST array.  This method must
   * be extended in order for your direct method to work!
   */
  function direct_response($response = array()) {
    // Update the pay object. Going through this method indicates that the 
    // transaction was successful.
    $this->activity->result = TRUE;
    $this->activity->action = 'complete';
    $this->activity->transaction_total = $this->activity->total;
    $this->activity->data[] = $response;
    switch ($response['pmt_status']) {
      case 'cancelled':
        $this->activity->action = 'cancelled';
        $this->activity->result = FALSE;
        break;
      case 'success':
        $this->activity->result = TRUE;
        $this->activity->action = 'complete';
        if (isset($response['pmt_amt'])) {
          $this->activity->transaction_total = $response['pmt_amt'];
        }
        if ( isset($response['pmt_amt']) && isset($this->activity->pay_transaction) ) {
          $this->activity->pay_transaction->total_paid = $response['pmt_amt'];
          $this->activity->pay_transaction->completed = time();
          $this->activity->pay_transaction->total = $this->activity->total;
          $this->activity->pay_transaction->state = 'complete';
          drupal_write_record('pay_transaction', $this->activity->pay_transaction);          
        }       
        break;
    }    
    $confirmation_url = $this->confirmation_url;    
    $data = array('pay_activity' => $this, 'confirmation_url' => $confirmation_url, 'response' => $response);
    drupal_alter('upay_directreponse_payactivity', $data);
    drupal_write_record('pay_activity', $this->activity);
    drupal_goto($data['confirmation_url']);
  }  

  function settings_form(&$form, &$form_state) {
    parent::settings_form($form, $form_state);
    $group = $this->handler();

    $form[$group]['upay_direct']['#type'] = 'fieldset';
    $form[$group]['upay_direct']['#collapsible'] = FALSE;
    $form[$group]['upay_direct']['#title'] = t('Touchnet uPay Payment Gateway Settings');
    $form[$group]['upay_direct']['#group'] = $group;

    $form[$group]['upay_direct']['upay_site_id'] = array(
      '#type' => 'textfield',
      '#title' => t('UPAY_SITE_ID'),
      '#description' => t('Your TouchNet UPAY_SITE_ID.'),
      '#default_value' => $this->upay_site_id,
      '#parents' => array($group, 'upay_site_id'),
      '#maxlength' => 64,
      '#required' => TRUE,
    );

    $form[$group]['upay_direct']['ext_trans_id_prefix'] = array(
      '#type' => 'textfield',
      '#title' => t('EXT_TRANS_ID prefix'),
      '#description' => t('The prefix to prepend to each EXT_TRANS_ID. This should be several characters that will help determine, on the TouchNet side, which site a transaction came from. Your TouchNet gateway administrator may request that you use a specific prefix for transactions originating from this site.'),
      '#default_value' => $this->ext_trans_id_prefix,
      '#parents' => array($group, 'ext_trans_id_prefix'),      
      '#maxlength' => 64,
      '#required' => TRUE,
    );

    $form[$group]['upay_direct']['url_live'] = array(
      '#type' => 'textfield',
      '#title' => t('Live URL'),
      '#description' => t('The TouchNet uPay URL to which <strong>live</strong> orders should be sent.'),
      '#default_value' => $this->url_live,
      '#parents' => array($group, 'url_live'),      
      '#maxlength' => 250,
      '#size' => 100,
      '#required' => TRUE,
    );

    $form[$group]['upay_direct']['url_test'] = array(
      '#type' => 'textfield',
      '#title' => t('Test URL'),
      '#description' => t('The TouchNet uPay URL to which <strong>test</strong> orders should be sent.'),
      '#default_value' => $this->url_test,
      '#parents' => array($group, 'url_test'),      
      '#maxlength' => 250,
      '#size' => 100,
    );

    $form[$group]['upay_direct']['test_mode'] = array(
      '#type' => 'checkbox',
      '#title' => t('Test mode'),
      '#description' => t('Enable this to use the <strong>test</strong> URL instead of the live URL.'),
      '#default_value' => $this->test_mode,
      '#parents' => array($group, 'test_mode'),
      '#element_validate' => array('upay_settings_testmode_validate'),
    );    

    $form[$group]['upay_direct']['logging'] = array(
      '#type' => 'checkbox',
      '#title' => t('Logging'),
      '#description' => t('Log notifications during processing.'),
      '#default_value' => $this->logging,
      '#parents' => array($group, 'logging'),
    );

    $form[$group]['upay_direct']['receives_post_back'] = array(
      '#type' => 'checkbox',
      '#title' => t('Receives Post Back'),
      '#description' => t('Once a uPay site has been configured to use a posting URL, transaction parameters will be passed by uPay to the posting URL. The customer’s browser is not navigated to the posting URL, but the parameters are posted to it. Check this box if payment method should be able to receive posted paraments. -- Advance Use, leave un-check if your not familiar --'),
      '#default_value' => $this->receives_post_back,
      '#parents' => array($group, 'receives_post_back'),
    );

    $form[$group]['upay_direct']['receives_posting_key'] = array(
      '#type' => 'textfield',
      '#title' => t('Post Back: Posting Key'),
      '#description' => t('A security value specified when the uPay site was built. (See “Miscellaneous: Links, URLs, and E-mail of uPay Technical Guides”.)'),
      '#default_value' => $this->receives_posting_key,
      '#parents' => array($group, 'receives_posting_key'),
    );    

    $form[$group]['upay_direct']['confirmation_url'] = array(
      '#type' => 'textfield',
      '#title' => t('Confirmation URL/Payment Complete URL'),
      '#description' => t('The URL to send users when payment transaction workflow is complete.'),
      '#default_value' => $this->confirmation_url,
      '#parents' => array($group, 'confirmation_url'),      
      '#maxlength' => 250,
      '#size' => 100,
    );

  }

  function form_submit(&$form, &$form_state) {
    // Find our transaction object provided by pay_form::form_submit().
    if (isset($form_state['pay_activity']) && $form_state['pay_activity']) {
      foreach ($form_state['pay_activity'] as $key => $activity) {
        if ($activity->pmid == $this->pmid) {
          // Load the activity as the 'current' one.
          $this->activity = pay_activity_load($activity->paid);
          $this->__construct($this->activity->data);
          $this->activity->action = $this->pay_form_action;

          // Effect a redirect to the direct payment gateway.
          if ($this->activity->action && $this->activity->action != 'pending') {
            unset($form_state['storage']);
            $form_state['rebuild'] = FALSE;
            $path = isset($_GET['q']) ? $_GET['q'] : '<front>';
            $origin = url($path, array('absolute' => TRUE));
            // get url of the form then set data origin to url of the form, just in case of a cancel or return situation.
            $this->activity->data['origin'] = $origin;
            $data = array('pay_activity' => $this, 'form' => $form, 'form_state' => $form_state);
            drupal_alter('upay_preintermediate_payactivity', $data);
            // payment activity action at this point is "pending"
            $this->activity->action = 'pending';
            $this->activity->save();
            $form_state['redirect'] = url('pay/upay/intermediate/'. $this->activity->paid, array('absolute' => TRUE));
            break;
          }
        }
      }
    }
  }
}
