<?php

/**
 * @file
 * Sample hooks demonstrating usage in Payment API UPAY payment gateway
 */

/**
 * @defgroup upay_hooks Upay Module Hooks
 * @{
 * upay's hooks enable other modules to intercept events, such
 * as the completion of a submission and its subsequent passing of post strings to upay payment processor. 
 */

/**
 * Alter the processed array of posted fields data coming from webform and about to be passed to upay payment processor
 * @param array $data 
 *   The posted data array
 * $data['pay_activity'] -- payment activity before rendered @ intermediate form page
 * $data['form_state'] -- useful context.. form state array
 * $data['form'] -- useful context.. form array
 */
function hook_upay_preintermediate_payactivity_alter(&$data) {
  $form = $data['form'];
  $form_state = $data['form_state'];
  // if form is coming a webform.
  if (!empty($form_state['values']['details']['sid'])) {
    $data['pay_activity']->activity->data['nid'] = $form['#node']->nid;
    $data['pay_activity']->activity->data['sid'] = $form_state['values']['details']['sid'];
  }
}

/**
 * Alter the processed array of payment activity data like pay actity object and confirmation url before we end the payment api process 
 * on a strictly redirect situation.
 * @param array $data 
 *   The posted data array
 * $data['pay_activity'] -- payment activity object after payment transaction 
 * $data['confirmation_url'] -- final destination of user after payment on a redirect situation.
 */
function hook_upay_directreponse_payactivity_alter(&$data) {
  // activity is a webform. 
  $sid = '';
  $nid = '';
  foreach ($data['pay_activity']->activity->pay_transaction->activity as $activity ) {      
    if ($activity->action !== 'complete') {
      continue;
    }
    if (!empty($activity->data['sid'])) {
      $sid = $activity->data['sid'];
    }
    if (!empty($activity->data['nid'])) {
      $nid = $activity->data['nid'];
    }
  }
  if (empty($sid) || empty($nid)) {
    return;
  }
  module_load_include('inc', 'webform', 'includes/webform.submissions');
  $new_submissions = webform_get_submissions(array('nid' => $nid, 'sid' => $sid));
  $submission = isset($new_submissions[$sid]) ? $new_submissions[$sid] : FALSE;
  if ( $submission === FALSE ) {
    return;
  }
  $node = node_load($nid);
  webform_submission_send_mail($node, $submission);
  // Clean up the redirect URL and filter it for webform tokens.
  $redirect_url = trim($node->webform['redirect_url']);
  $redirect_url = _webform_filter_values($redirect_url, $node, $submission, NULL, FALSE, TRUE);

  // Remove the domain name from the redirect.
  $redirect_url = preg_replace('/^' . preg_quote($GLOBALS['base_url'], '/') . '\//', '', $redirect_url);
  if ($redirect_url == '<none>') {
    $redirect = NULL;
  }
  elseif ($redirect_url == '<confirmation>') {
    $redirect = 'node/' . $node->nid . '/done';
  }
  elseif (valid_url($redirect_url, TRUE)) {
    $redirect = $redirect_url;
  }
  if (!empty($redirect)) {
    $data['confirmation_url'] = $redirect;
  }
}

/**
 * @}
 */